@@ -8,7 +8,6 @@ import click
 from .click_common import EnumType, command, format_output
 from .device import Device, DeviceStatus
 from .exceptions import DeviceException
-from .utils import deprecated
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -348,22 +347,3 @@ class AirFresh(Device):
             return self.send("set_ptc_state", ["on"])
         else:
             return self.send("set_ptc_state", ["off"])
-
-
-@deprecated(
-    "This will be removed in the future, use AirFresh(..., model='zhimi.airfresh.va4'"
-)
-class AirFreshVA4(AirFresh):
-    """Main class representing the air fresh va4."""
-
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-    ) -> None:
-        super().__init__(
-            ip, token, start_id, debug, lazy_discover, model=MODEL_AIRFRESH_VA4
-        )
