@@ -3,7 +3,6 @@
 import logging
 from typing import TYPE_CHECKING
 
-from ..device import Device
 from ..exceptions import DeviceException
 
 _LOGGER = logging.getLogger(__name__)
@@ -13,7 +12,7 @@ if TYPE_CHECKING:
     from .gateway import Gateway
 
 
-class GatewayDevice(Device):
+class GatewayDevice:
     """GatewayDevice class Specifies the init method for all gateway device
     functionalities."""
 
@@ -21,11 +20,6 @@ class GatewayDevice(Device):
 
     def __init__(
         self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
         parent: "Gateway" = None,
     ) -> None:
         if parent is None:
@@ -34,4 +28,3 @@ class GatewayDevice(Device):
             )
 
         self._gateway = parent
-        super().__init__(ip, token, start_id, debug, lazy_discover)
